@@ -2,9 +2,9 @@
 # and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2020 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
-#           © 2019-2020 Richard Machado <rmlibre@riseup.net>
+#           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
 #
 
@@ -44,6 +44,9 @@ from . import DebugControl
 from .commons import Namespace
 
 
+this_second = lambda: int(time())
+
+
 thread_pool = ThreadPoolExecutor()
 process_pool = ProcessPoolExecutor()
 default_loop = asyncio.get_event_loop()
@@ -323,6 +326,7 @@ __extras = {
     "gather": gather,
     "new_task": new_task,
     "new_future": new_future,
+    "this_second": this_second,
     "thread_pool": thread_pool,
     "process_pool": process_pool,
     "default_loop": default_loop,
