@@ -2,9 +2,9 @@
 # and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2020 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
-#           © 2019-2020 Richard Machado <rmlibre@riseup.net>
+#           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
 #
 
@@ -14,10 +14,13 @@ __all__ = [
     "bits",
     "primes",
     "Namespace",
+    "PrimeGroups",
     "WORD_LIST",
     "ASCII_TABLE",
     "BYTES_TABLE",
+    "BASE_36_TABLE",
     "BASE_64_TABLE",
+    "URL_SAFE_TABLE",
     "ASCII_TABLE_128",
     "ONION_CHAR_TABLE",
     "ASCII_ALPHANUMERIC",
@@ -34,8 +37,8 @@ import sys
 import copy
 import types
 import asyncio
-from hashlib import sha3_256
 from os import linesep
+from hashlib import sha3_256
 from .__datasets import *
 from . import DebugControl
 
@@ -45,7 +48,7 @@ async def aimport_namespace(
 ):
     """
     Takes a ``dictionary``, such as ``globals()``, and copies the
-    key-value pairs from the ``mapping`` kwarg into ``dictionary``.
+    key-value pairs from the ``mapping`` kwarg into it.
     """
     if deepcopy == True:
         dictionary.update(copy.deepcopy(mapping))
@@ -57,7 +60,7 @@ async def aimport_namespace(
 def import_namespace(dictionary=None, *, mapping=None, deepcopy=False):
     """
     Takes a ``dictionary``, such as ``globals()``, and copies the
-    key-value pairs from the ``mapping`` kwarg into ``dictionary``.
+    key-value pairs from the ``mapping`` kwarg into it.
     """
     if deepcopy == True:
         dictionary.update(copy.deepcopy(mapping))
@@ -130,7 +133,7 @@ def redact_keys(string, *, rule=r"[0-9a-fA-F]{64,}"):
     return string
 
 
-class Namespace:
+class Namespace():
     """
     A simple wrapper for turning mappings into Namespace objects that
     allow dotted lookup and assignment on those mappings. Also, provides
@@ -145,14 +148,12 @@ class Namespace:
     aimport_namespace = staticmethod(aimport_namespace)
     import_namespace = staticmethod(import_namespace)
 
-    def __init__(self, mapping=None, **kwargs):
+    def __init__(self, mapping={}, **kwargs):
         """
         Maps the user-defined mapping & kwargs to the Namespace's
         instance dictionary.
         """
-        self.__dict__.update(
-            {**mapping, **kwargs} if mapping else {**kwargs}
-        )
+        self.__dict__.update({**mapping, **kwargs})
 
     @property
     def __all__(self):
@@ -256,6 +257,9 @@ class Namespace:
         """
         return self.__dict__
 
+    def keys(self):
+        return dir(self)
+
 
 __extras = {
     # A domain-specific namespace for networking & communications
@@ -266,26 +270,28 @@ __extras = {
     "ASCII_ALPHANUMERIC": ASCII_ALPHANUMERIC,
     "ASCII_TABLE": ASCII_TABLE,
     "ASCII_TABLE_128": ASCII_TABLE_128,
+    "BASE_36_TABLE": BASE_36_TABLE,
     "BASE_64_TABLE": BASE_64_TABLE,
     "BYTES_TABLE": BYTES_TABLE,
     "CHANNEL": "channel",
     "CHANNELS": "channels",
     "CIPHERED_SALT": "ciphered_salt",
     "CIPHERTEXT": "ciphertext",
+    "CIPHERTEXT_IS_NOT_BYTES": "Ciphertext is not in bytes format.",
     "CLIENT": "client",
     "CORRUPT": "corrupt_connection",
     "DECRYPT": "decrypt",
-    "DH_PRIME_4096_BIT_GROUP_16": DH_PRIME_4096_BIT_GROUP_16,
-    "DH_GENERATOR_4096_BIT_GROUP_16": DH_GENERATOR_4096_BIT_GROUP_16,
     "DIRECTORY": "directory",
     "ENCRYPT": "encrypt",
     "FAILED": "failed",
     "GUEST": "guest",
     "HMAC": "hmac",
+    "HMAC_BYTES": 32,
     "HTTP": "http",
     "HTTPS": "https",
     "ID": "contact_identifier",
     "INACTIVE": "terminated_connection",
+    "INVALID_CIPHERTEXT_LENGTH": "The length of ciphertext is invalid.",
     "KEEP_ALIVE": "keep_alive",
     "KEY": "key",
     "KEY_ID": "key_id",
@@ -299,10 +305,10 @@ __extras = {
     "MESSAGES": "message_archive",
     "METADATA": "metadata",
     "METATAG": sha3_256(f"__metatags__{NONE}".encode()).hexdigest(),
-    "Namespace": Namespace,
     "NEW_CONTACT": "new_contact",
     "NEXT_KEYED_PASSWORD": "next_keyed_password",
     "NEXT_SALT": "next_salt",
+    "NO_PROFILE_OR_CORRUPT": "Profile doesn't exist or is corrupt.",
     "NONE": NONE,
     "NUM": NUM,
     "OLD_KEY": "last_shared_key",
@@ -321,6 +327,7 @@ __extras = {
     "REGISTRATION": "registration",
     "RETRY": "retry",
     "SALT": "salt",
+    "SALT_BYTES": 32,
     "SECRET": "secret",
     "SEED": "seed",
     "SENDER": "sender",
@@ -337,15 +344,19 @@ __extras = {
     "STATUS": "status",
     "SUCCESS": "success",
     "TB_PORT": 9150,
+    "ROPAKE_TIMEOUT": 0,
     "TOR_PORT": 9050,
     "UNSENT_MESSAGES": "unsent_message_archive",
     "URL": "url",
+    "URL_SAFE_TABLE": URL_SAFE_TABLE,
     "USER_MOD": "user_prime_modulus",
     "USER_PUB": "user_public_key_part",
     "USER_SECRET": "user_secret",
     "VERIFICATION": "verification",
     "VERIFID": "verification_code",
     "WORD_LIST": WORD_LIST,
+    "Namespace": Namespace,
+    "PrimeGroups": PrimeGroups,
     "__doc__": __doc__,
     "__main_exports__": __all__,
     "__package__": "aiootp",
