@@ -2,9 +2,9 @@
 # and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2020 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
-#           © 2019-2020 Richard Machado <rmlibre@riseup.net>
+#           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
 #
 
@@ -27,35 +27,32 @@ A collection of highlevel tools for creating & managing symmetric keys.
 
 from .asynchs import *
 from .commons import *
-from .randoms import salt
-from .randoms import asalt
-from .randoms import csprbg
-from .randoms import csprng
-from .randoms import acsprng
-from .randoms import token_bytes
-from .randoms import atoken_bytes
-from .ciphers import keys
-from .ciphers import akeys
+from .randoms import salt, asalt
+from .randoms import csprbg, acsprbg
+from .randoms import csprng, acsprng
+from .randoms import random_256, arandom_256
+from .randoms import random_512, arandom_512
+from .randoms import token_bytes, atoken_bytes
+from .ciphers import Ropake
+from .ciphers import X25519
+from .ciphers import Ed25519
 from .ciphers import Passcrypt
-from .ciphers import passcrypt
-from .ciphers import apasscrypt
-from .ciphers import bytes_keys
-from .ciphers import abytes_keys
 from .ciphers import OneTimePad
-from .ciphers import keypair_ratchets
-from .ciphers import akeypair_ratchets
+from .ciphers import keys, akeys
+from .ciphers import passcrypt, apasscrypt
+from .ciphers import bytes_keys, abytes_keys
+from .ciphers import padding_key, apadding_key
+from .ciphers import keypair_ratchets, akeypair_ratchets
 from .generics import azip
 from .generics import is_iterable
 from .generics import comprehension
-from .generics import sha_256
-from .generics import asha_256
-from .generics import sha_256_hmac
-from .generics import asha_256_hmac
+from .generics import sha_256, asha_256
+from .generics import sha_256_hmac, asha_256_hmac
 from .generics import convert_static_method_to_member
 
 
 @comprehension()
-async def atable_key_gen(key=None, table=ASCII_TABLE):
+async def atable_keystream(key=None, table=ASCII_TABLE):
     """
     This table based key generator function converts any key string
     containing an arbitrary set of characters, into another key string
@@ -79,7 +76,7 @@ async def atable_key_gen(key=None, table=ASCII_TABLE):
 
     # To produce a 60 byte key of characters from the default table
     key = "hotdiggitydog_thischowisyummy"
-    async with atable_key_gen(key=key) as generator:
+    async with atable_keystream(key=key) as generator:
         new_key = await generator()
         assert new_key != await generator()
     print(new_key)
@@ -88,12 +85,13 @@ async def atable_key_gen(key=None, table=ASCII_TABLE):
     if not key:
         key = await acsprng()
     size = len(table[:])
-    async for key_portion in akeys(key, key).aint(16).ato_base(size, table):
+    keystream = akeys(key, salt=key).aint(16).ato_base(size, table)
+    async for key_portion in keystream:
         yield key_portion
 
 
 @comprehension()
-def table_key_gen(key=None, table=ASCII_TABLE):
+def table_keystream(key=None, table=ASCII_TABLE):
     """
     This table based key generator function converts any key string
     containing an arbitrary set of characters, into another key string
@@ -115,7 +113,7 @@ def table_key_gen(key=None, table=ASCII_TABLE):
 
     Usage Example:
     key = "hotdiggitydog_thischowisyummy"
-    with table_key_gen(key=key) as generator:
+    with table_keystream(key=key) as generator:
         new_key = generator()
         assert new_key != generator()
     print(new_key)
@@ -124,7 +122,8 @@ def table_key_gen(key=None, table=ASCII_TABLE):
     if not key:
         key = csprng()
     size = len(table[:])
-    for key_portion in keys(key, key).int(16).to_base(size, table):
+    keystream = keys(key, salt=key).int(16).to_base(size, table)
+    for key_portion in keystream:
         yield key_portion
 
 
@@ -160,7 +159,7 @@ async def atable_key(key=None, table=ASCII_TABLE, size=64):
     print(new_key)
     >>> #mE)bOQD@lY%]Qwpb9Zi^32]jteVg
     """
-    async with atable_key_gen(key=key, table=table) as generator:
+    async with atable_keystream(key=key, table=table) as generator:
         new_key = await generator()
         while len(new_key) < size:
             new_key += await generator()
@@ -198,7 +197,7 @@ def table_key(key=None, table=ASCII_TABLE, size=64):
     print(new_key)
     >>> #mE)bOQD@lY%]Qwpb9Zi^32]jteVg
     """
-    with table_key_gen(key=key, table=table) as generator:
+    with table_keystream(key=key, table=table) as generator:
         new_key = generator()
         while len(new_key) < size:
             new_key += generator()
@@ -219,7 +218,7 @@ async def amnemonic(key, salt=None, words=WORD_LIST):
     length = len(words)
     salt = salt if salt else await acsprng()
     key = await apasscrypt(key, salt)
-    entropy = abytes_keys(key, salt, key)
+    entropy = abytes_keys(key, salt=salt, pid=key)
     async with entropy.abytes_to_int().arelay(salt) as indexes:
         while True:
             if translate:
@@ -241,7 +240,7 @@ def mnemonic(key, salt=None, words=WORD_LIST):
     length = len(words)
     salt = salt if salt else csprng()
     key = passcrypt(key, salt)
-    entropy = bytes_keys(key, salt, key)
+    entropy = bytes_keys(key, salt=salt, pid=key)
     with entropy.bytes_to_int().relay(salt) as indexes:
         while True:
             if translate:
@@ -280,17 +279,18 @@ class AsyncKeys:
     """
 
     instance_methods = {
-        akeys, abytes_keys, amnemonic, atable_key, atable_key_gen
+        akeys, abytes_keys, amnemonic, atable_key, atable_keystream
     }
 
     asalt = staticmethod(asalt)
     akeys = staticmethod(akeys)
     akeypair = staticmethod(akeypair)
     amnemonic = staticmethod(amnemonic)
+    apadding_key = staticmethod(apadding_key)
     apasscrypt = staticmethod(apasscrypt)
     abytes_keys = staticmethod(abytes_keys)
     atable_key = staticmethod(atable_key)
-    atable_key_gen = staticmethod(atable_key_gen)
+    atable_keystream = staticmethod(atable_keystream)
     akeypair_ratchets = staticmethod(akeypair_ratchets)
 
     def __init__(self, key=None):
@@ -300,11 +300,7 @@ class AsyncKeys:
         ``key`` argument is not passed then a new 512-bit random key is
         created.
         """
-        self._key = key if key else salt()
-        for method in self.instance_methods:
-            convert_static_method_to_member(
-                self, method.__name__, method, key=self.key,
-            )
+        self._reset(key=key)
         self.apasscrypt = self._apasscrypt
 
     def __getitem__(self, pid=""):
@@ -342,7 +338,7 @@ class AsyncKeys:
         return self._key
 
     async def ahmac(
-        self, data=None, *, key=None, hasher=asha_256_hmac
+        self, data, *, key=None, hasher=asha_256_hmac
     ):
         """
         Creates an HMAC code of ``data`` using ``key``  or the
@@ -352,7 +348,7 @@ class AsyncKeys:
         return await hasher(data, key=key if key else self.key)
 
     async def atest_hmac(
-        self, data=None, hmac=None, *, key=None, hasher=asha_256_hmac
+        self, data, *, hmac=None, key=None, hasher=asha_256_hmac
     ):
         """
         Tests if the given ``hmac`` of some ``data`` is valid with a
@@ -402,6 +398,17 @@ class AsyncKeys:
         else:
             return False
 
+    def _reset(self, key=None):
+        """
+        Replaces the stored instance key used to create deterministic
+        streams of key material &, create & validate HMAC codes.
+        """
+        self._key = key if key else csprng()
+        for method in self.instance_methods:
+            convert_static_method_to_member(
+                self, method.__name__, method, key=self.key,
+            )
+
     async def areset(self, key=None):
         """
         Replaces the stored instance key used to create deterministic
@@ -441,17 +448,18 @@ class Keys:
     """
 
     instance_methods = {
-        keys, bytes_keys, mnemonic, table_key, table_key_gen
+        keys, bytes_keys, mnemonic, table_key, table_keystream
     }
 
     salt = staticmethod(salt)
     keys = staticmethod(keys)
     keypair = staticmethod(keypair)
     mnemonic = staticmethod(mnemonic)
+    padding_key = staticmethod(padding_key)
     passcrypt = staticmethod(passcrypt)
     bytes_keys = staticmethod(bytes_keys)
     table_key = staticmethod(table_key)
-    table_key_gen = staticmethod(table_key_gen)
+    table_keystream = staticmethod(table_keystream)
     keypair_ratchets = staticmethod(keypair_ratchets)
 
     def __init__(self, key=None):
@@ -498,7 +506,7 @@ class Keys:
         """
         return self._key
 
-    def hmac(self, data=None, *, key=None, hasher=sha_256_hmac):
+    def hmac(self, data, *, key=None, hasher=sha_256_hmac):
         """
         Creates an HMAC code of ``data`` using ``key``  or the
         instance's ``self.key`` if it's not supplied & the hashing
@@ -507,7 +515,7 @@ class Keys:
         return hasher(data, key=key if key else self.key)
 
     def test_hmac(
-        self, data=None, hmac=None, *, key=None, hasher=sha_256_hmac
+        self, data, *, hmac=None, key=None, hasher=sha_256_hmac
     ):
         """
         Tests if the given ``hmac`` of some ``data`` is valid with a
@@ -604,23 +612,40 @@ def insert_keyrings(self, key=None):
 __extras = {
     "AsyncKeys": AsyncKeys,
     "Keys": Keys,
+    "X25519": X25519,
+    "Ed25519": Ed25519,
     "__doc__": __doc__,
     "__main_exports__": __all__,
     "__package__": "aiootp",
-    "ainsert_keyrings": ainsert_keyrings,
-    "insert_keyrings": insert_keyrings,
+    "_ainsert_keyrings": ainsert_keyrings,
+    "_insert_keyrings": insert_keyrings,
+    "asalt": asalt,
+    "salt": salt,
+    "acsprng": acsprng,
+    "csprng": csprng,
+    "acsprbg": acsprbg,
+    "csprbg": csprbg,
     "akeys": akeys,
     "keys": keys,
+    "abytes_keys": abytes_keys,
+    "bytes_keys": bytes_keys,
+    "amnemonic": amnemonic,
     "mnemonic": mnemonic,
     "akeypair": akeypair,
     "keypair": keypair,
     "akeypair_ratchets": akeypair_ratchets,
     "keypair_ratchets": keypair_ratchets,
-    "amnemonic": amnemonic,
+    "apadding_key": apadding_key,
+    "padding_key": padding_key,
+    "protocols": X25519.protocols,
     "atable_key": atable_key,
     "table_key": table_key,
-    "atable_key_gen": atable_key_gen,
-    "table_key_gen": table_key_gen,
+    "atable_keystream": atable_keystream,
+    "table_keystream": table_keystream,
+    "arandom_256": arandom_256,
+    "random_256": random_256,
+    "arandom_512": arandom_512,
+    "random_512": random_512,
 }
 
 
