@@ -2,9 +2,9 @@
 # networking over tor v3 onion services.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
-# Copyright © 2019-2020 Gonzo Investigatory Journalism Agency, LLC
+# Copyright © 2019-2021 Gonzo Investigatory Journalism Agency, LLC
 #            <gonzo.development@protonmail.ch>
-#          © 2019-2020 Richard Machado <rmlibre@riseup.net>
+#           © 2019-2021 Richard Machado <rmlibre@riseup.net>
 # All rights reserved.
 #
 
@@ -20,6 +20,7 @@ __all__ = [
     "test_AsyncDatabase_instance",
     "test_Database_cipher",
     "test_AsyncDatabase_cipher",
+    "test_user_profiles",
     "__all__",
 ]
 
@@ -28,8 +29,6 @@ tag = "testing"
 atag = "a" + tag
 metatag = "clients"
 ametatag = "a" + metatag
-depth = 100
-key = csprng()
 test_data = {
     "floats": 10000.243,
     "dicts": {"testing": {}},
@@ -44,30 +43,6 @@ atest_data = {
 }
 
 
-@pytest.fixture(scope="module")
-def database():
-    print("setup".center(15, "-"))
-
-    db = Database(key=key, password_depth=depth)
-    db.save()
-    yield db
-
-    print("teardown".center(18, "-"))
-    db.delete_database()
-
-
-@pytest.fixture(scope="module")
-def async_database():
-    print("setup".center(15, "-"))
-
-    db = run(AsyncDatabase(key=key, password_depth=depth))
-    yield db
-
-    print("teardown".center(18, "-"))
-    run(db.asave())
-    run(db.adelete_database())
-
-
 def test_Database_instance(database):
     db = Database(key=key, password_depth=depth)
 
@@ -140,8 +115,10 @@ def metatag_isnt_ametatag_but_equal(child, achild, db, adb):
 def databases_save_metatag_files(db, adb, filename, afilename):
     assert not (db.directory / filename).exists()
     assert not (adb.directory / afilename).exists()
-    db.save()
-    run(adb.asave())
+    with db:
+        pass
+    run(adb.__aenter__())
+    run(adb.__aexit__())
     assert (db.directory / filename).exists()
     assert (adb.directory / afilename).exists()
     assert db.clients[tag] == adb.aclients[atag]
@@ -178,3 +155,41 @@ def test_tags_metatags():
 
     database.delete_database()
     run(async_database.adelete_database())
+
+
+async def async_user_profiles(async_database):
+    adb = async_database
+    tokens = await adb.agenerate_profile_tokens(**PROFILE_AND_SETTINGS)
+    user = await adb.agenerate_profile(tokens)
+
+    async with user:
+        user[atag] = atest_data
+
+    user_copy = await adb.aload_profile(tokens)
+    assert user[atag] == user_copy[atag]
+    assert user[atag] is not user_copy[atag]
+
+    await adb.adelete_profile(tokens)
+    return user_copy
+
+
+def user_profiles(database):
+    db = database
+    tokens = db.generate_profile_tokens(**PROFILE_AND_SETTINGS)
+    user = db.generate_profile(tokens)
+
+    with user:
+        user[tag] = test_data
+
+    user_copy = db.load_profile(tokens)
+    assert user[tag] == user_copy[tag]
+    assert user[tag] is not user_copy[tag]
+
+    db.delete_profile(tokens)
+    return user_copy
+
+
+def test_user_profiles(database, async_database):
+    profile = user_profiles(database)
+    aprofile = run(async_user_profiles(async_database))
+
